#
# spec file for package python-psycopg-c
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-psycopg-c
# This needs to upgraded in lockstep with python-psycopg
Version:        3.2.6
Release:        1.1
Summary:        PostgreSQL database adapter for Python -- C optimisation distribution
License:        LGPL-3.0-only
URL:            https://psycopg.org/psycopg3/
Source:         https://files.pythonhosted.org/packages/source/p/psycopg-c/psycopg_c-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 49.2.0}
BuildRequires:  %{python_module tomli >= 2.0.1}
BuildRequires:  %{python_module wheel >= 0.37}
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  postgresql17-server-devel
BuildRequires:  python-rpm-macros
%python_subpackages

%description
PostgreSQL database adapter for Python -- C optimisation distribution

%prep
%autosetup -p1 -n psycopg_c-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

# Tested in python-psycopg

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitearch}/psycopg_c
%{python_sitearch}/psycopg_c-%{version}.dist-info

%changelog
* Wed Apr  9 2025 Antonio Larrosa <alarrosa@suse.com>
- update to 3.2.6:
  * Fix connection semantic when using
    target_session_attrs=prefer-standby (ticket #1021).
- update to 3.2.5:
  * 3x faster UUID loading thanks to C implementation
    (tickets #447, #998).
- update to 3.2.4:
  * Don’t lose notifies received whilst the notifies() iterator
    is not running (ticket #962).
  * Make sure that the notifies callback is called during the use
    of the notifies() generator (ticket #972).
  * Raise the correct error returned by the database (such as
    AdminShutdown or IdleInTransactionSessionTimeout) instead of
    a generic OperationalError when a server error causes a client
    disconnection (ticket #988).
  * Build macOS dependencies from sources instead using the
    Homebrew versions in order to avoid problems with
    MACOSX_DEPLOYMENT_TARGET (ticket #858).
  * Bump libpq to 17.2 in Linux and macOS binary packages.
  * Bump libpq to 16.4 in Windows binary packages, using the
    vcpkg library (ticket #966).
* Tue Nov 12 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.3:
  * Release binary packages including PostgreSQL 17 libpq
  * Drop TypeDef specifications as string from public modules, as
    they cannot be composed by users as typing objects previously
    could (ticket #860).
  * Release Python 3.13 binary packages.
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.1:
  * Fix packaging metadata breaking [c], [binary] dependencies
  * Add support for integer, floating point, boolean NumPy scalar
    types (ticket #332).
  * Add timeout and stop_after parameters to Connection.notifies()
  * Allow dumpers to return None, to be converted to NULL (ticket
  * Add Raw query cursors to execute queries using placeholders in
    PostgreSQL format ($1, $2…) (tickets #560, #839).
  * Add capabilities object to inspect the libpq capabilities
  * Add scalar_row to return scalar values from a query
  * Add cancel_safe() for encrypted and non-blocking cancellation when
    using libpq v17. Use such method internally to implement
    KeyboardInterrupt and copy termination
  * The context parameter of sql objects as_string() and as_bytes()
    methods is now optional
  * Add set_autocommit() on sync connections, and similar transaction
    control methods available on the async connections.
  * Add a size parameter to stream() to enable results retrieval in
    chunks instead of row-by-row
* Thu May 16 2024 Dirk Müller <dmueller@suse.com>
- update to 3.1.19:
  * Fix unaligned access undefined behaviour in C extension (ticket #734).
  * Fix excessive stripping of error message prefixes (ticket #752).
  * Allow to specify the connect_timeout connection parameter as float (ticket #796).
  * Improve COPY performance on macOS (ticket #745).
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 3.1.18:
  * Fix possible deadlock on pipeline exit (ticket #685).
  * Fix overflow loading large intervals in C module (ticket #719).
  * Fix compatibility with musl libc distributions affected
    by CPython issue #65821 (ticket #725).
* Mon Jan 15 2024 Antonio Larrosa <alarrosa@suse.com>
- Use %%sle15_python_module_pythons
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 3.1.17:
  * add missing enum entries
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 3.1.16:
  * version only update
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.15:
  * Fix use of service in connection string
  * Fix async connection to hosts resolving to multiple IP
    addresses
  * Respect the PGCONNECT_TIMEOUT environment variable to
    determine the connection timeout.
  * Psycopg 3.1.14
  * Fix interaction with gevent (ticket #527).
  * Add support for PyPy (ticket #686).
* Fri Nov 24 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to 3.1.13:
  * Raise DataError instead of whatever internal failure trying to
    dump a time object with with a tzinfo specified as ZoneInfo
    (ambiguous offset, see ticket #652).
  * Handle gracefully EINTR on signals instead of raising
    InterruptedError, consistently with PEP 475 guideline
    (ticket #667).
  * Fix support for connection strings with multiple hosts/ports
    and for the load_balance_hosts connection parameter
    (ticket #674).
  * Fix memory leak receiving notifications in Python
    implementation (ticket #679).
- Update to 3.1.12:
  * Fix possible hanging if a connection is closed while querying
    (ticket #608).
  * Fix memory leak when register_*() functions are called
    repeatedly (ticket #647).
  * Release Python 3.12 binary packages.
- Update to 3.1.11:
  * Avoid caching the parsing results of large queries to avoid
    excessive memory usage (ticket #628).
  * Fix integer overflow in C/binary extension with OID > 2^31
    (ticket #630).
  * Fix loading of intervals with days and months or years
    (ticket #643).
  * Work around excessive CPU usage on Windows (reported in
    ticket #645).
  * Fix building on Solaris and derivatives (ticket #632).
  * Fix possible lack of critical section guard in
    async executemany().
  * Fix missing pipeline fetch in async scroll().
  * Build binary packages with libpq 15.4, which allows
    group-readable permissions on the SSL certificate on the client
    (ticket #528).
- Update to 3.1.10
  * Allow JSON dumpers to dump bytes directly instead of str, for
    better compatibility with libraries like orjson and msgspec
    (ticket #569)
  * Fix prepared statement cache validation when exiting pipeline
    mode (or executemany()) in case an error occurred within the
    pipeline (ticket #585).
  * Fix connect() to avoid “leaking” an open PGconn attached to
    the OperationalError in case of connection failure.
    Error.pgconn is now a shallow copy of the real libpq
    connection, and the latter is closed before the exception
    propagates (ticket #565).
  * Fix possible (ignored) exception on objects deletion
    (ticket #591).
  * Don’t clobber a Python exception raised during COPY FROM with
    the resulting QueryCanceled raised as a consequence
    (ticket #593).
  * Fix resetting Connection.read_only and deferrable to their
    default value using None (ticket #612).
  * Add support for Python 3.12.
* Wed Jul 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 3.1.9
